/**
 *
 *  Betterville Lady Stormshadow
 *  @author Drakkos
 *  @started 29/03/2009
 *
 */
 
#include "path.h"

// We've created a simple NPC inherit, and this is the one we use 
// instead of /obj/monster
inherit INHERITS + "betterville_npc";

object spare_dress;

void setup() {
  object dress;
  // Normal setup information - nothing unusual here.
  set_name ("stormshadow");
  set_short ("Lady Tempesre Stormshadow");
  add_property ("determinate", "");
  set_long ("This is Lady Tempesre Stormshadow, an older but still "
    "attractive woman with a noble bearing.  Her eyes are bright and "
    "calculating, sizing up the value of all that her gaze falls "
    "upon.\n");

  add_adjective (({"lady", "tempesre"}));
  add_alias (({"lady", "tempesre"}));
  
  set_gender (2);
  basic_setup ("human", "wizard", 150 + random (50));
  setup_nationality ("/std/nationality/genua", "Genua");

  // Setup the load chats.
  load_chat(120,
  ({
    1, "' Come buy one of my beautiful dresses!",
    1, "' Show the Beast you care with a wonderful outfit!",
    1, "' The Beast wouldn't give his heart to a poorly dressed bumpkin!",
    1, "' Follow your star, straight to my shop!",
    1, "' Beauty is only skin-deep, but you can sort out 'ugly' with a "
      "dress!",
  }));

  // Set up the attack chats.
  load_a_chat(120,
  ({
    1, "' You don't know how much you're going to regret this!",
    1, "' Can your mother sew?  She'll need to be able to.",
    1, "' Help!  Help!",
    1, "' You're no handsome prince, what do you think you're doing?",
  }));

  add_respond_to_with( ({ "@say", 
       ({"where"}), ({"you", "tempesre", "stormshadow"}), ({"from"}), }), 
      "' I am Lady Tempesre Stormshadow, hailing from the diamond "
       "city of Genua!");  

  add_respond_to_with( ({ "@say", 
       ({"about"}), ({"genua"}), }), 
      ":emote shuffles her feet.");  

  add_respond_to_with( ({ "@say", 
       ({"genua"}), }), 
      "' Yes, I come from Genua, which is far away from here!  In... uh... "
        "another country!");  

  add_respond_to_with( ({ "@say", 
       ({"beast"}), }), 
      "' I knew the beast once.  Once... upon a dream.  Before the curse.");  

  add_respond_to_with( ({ "@say", 
       ({"curse"}), }), 
      "' He was a good man, before Lilith.  Before... I spurned him.");  
    
  add_respond_to_with( ({ "@say", 
       ({"lilith"}), }), 
      "' Lilith!  She of her vicious cruelty!  She cursed him to the form "
        "of a beast as part of her horrible fascination with stories.");  

  add_respond_to_with( ({ "@say", 
       ({"story", "stories", "cruelty"}), }), 
      "' Stories are powerful.  I will say no more... but if you should "
        "ever make your way to a library, you could find out what happens "
        "when stories run amok.  Read about Genua.");  

  add_respond_to_with( ({ "@say", 
       ({"spurned", "spurn", "love", "loved"}), }), 
      "' I... loved him once.  I still do, in my way.  But I cannot bring "
        "myself to look upon him now.  That is my weakness, my curse.");  
  
  dress = clone_object (ITEMS + "beautiful_dress");
  dress->set_motif ("forgotten love");
  dress->move (this_object());
  
  init_equip();

  // Give her the two spells we defined.
  add_spell ("teleport", MAGIC + "tempesre_teleport", "cast_spell");
  add_spell ("dresses", MAGIC + "dancing_dress", "cast_spell");

  // Add actions to handle the casting of those two spells
  add_combat_action (25, "cast dresses", ({"cast_dresses"}));
  add_combat_action (10, "cast teleport", ({"cast_teleport"}));
  
}

int second_life() {
  // Get the list of attackers for this object.
  object *enemies = this_object()->query_attacker_list();
  
  do_command ("' The Beast... shall hear of this...");
  
  foreach (object enemy in enemies) {
    // Add each of them to be punished.
    DISEMBOWEL_HANDLER->add_to_punish (enemy);
  }
}

/**
 *
 *  This is the method that gets triggered when the cast dresses
 *  combat action gets executed
 *
 *  @param        attacker        The object making the attack
 *  @param        defender        The object making the defence
 *
 */

void cast_dresses(object attacker, object defender) {

  // Check to see if this NPC is currently casting a spell.
  if (query_casting_spell()) {
    return;
  }
  
  // Check to see if we cast this specific spell too recently to
  // cast it again.
  if (query_property ("cast dresses")) {
    return;
  }

  // Cheat like bastards.  Don't worry about supplying her with dresses 
  // as components, let her use her stock.  
  if (!spare_dress) {   
    tell_room (environment (this_object()), one_short() + " grabs a dress "
      "from one of the racks.\n");
    spare_dress = clone_object (ITEMS + "beautiful_dress");
    spare_dress->move (this_object());
  }
  
  // Everything is fine, cast the spell.
  init_command ("cast dresses", 1);
  // Add a property so it's at least 15 seconds until we cast this again.
  add_property ("cast dresses", 1, 15);
  
}

/**
 *
 *  This is the method that gets triggered when the cast teleport
 *  combat action gets executed
 *
 *  @param        attacker        The object making the attack
 *  @param        defender        The object making the defence
 *
 */

void cast_teleport(object attacker, object defender) {
  object enemy;

  // Check to see if this NPC is currently casting a spell.
  if (query_casting_spell()) {
    return;
  }
  
  // Check to see if we cast this specific spell too recently to
  // cast it again.  
  if (query_property ("cast teleport")) {
    return;
  }
  
  // Give us a consistent object reference for the one 
  // we're attacking.  Sometimes attacker will be us, sometimes 
  // defender will be us.  Make it so that whichever one is our
  // enemy, we can use the variable 'enemy'
  if (attacker == this_object()) {
    enemy = defender;
  }
  else {
    enemy = attacker;
  }

  // Cast the spell
  init_command ("cast teleport on " + file_name (enemy), 1);
  // Add a property that means we won't cast it again for at least 30 seconds.  
  add_property ("cast teleport", 1, 30);
}